# sml_theory

Demonstrates propositions of supervised machine learning theories

## Installation

```bash
$ pip install smltheory
```

## Usage

`sml_theory` can be used to demonstrate propositions of
supervised machine learning theories. Specifically, the functions
demonstrate the propositions of excess risk decomposition
and the bias-variance tradeoff. 

```python
#compute Bayes risk 



```




## Contributing

Interested in contributing? Check out the contributing guidelines. Please note that this project is released with a Code of Conduct. By contributing to this project, you agree to abide by its terms.

## License

`smltheory` was created by Sebastian Sciarra. It is licensed under the terms of the MIT license.

## Credits

`smltheory` was created with [`cookiecutter`](https://cookiecutter.readthedocs.io/en/latest/) and the `py-pkgs-cookiecutter` [template](https://github.com/py-pkgs/py-pkgs-cookiecutter).
